pdca

package
v0.0.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 21, 2026 License: MIT Imports: 34 Imported by: 0

Documentation

Index

Constants

const (
	RolePlan  = "plan"
	RoleDo    = "do"
	RoleCheck = "check"
	RoleAct   = "act"
)

Variables

This section is empty.

Functions

func NewLoopAgent

func NewLoopAgent(ctx context.Context, cfg config.Config, store *db.Store, tracker task.Tracker, runInput AgentInput, baseBranch string, maxIterations int) (agent.Agent, error)

NewLoopAgent creates and configures the PDCA loop agent with role subagents.

func Role

func Role(name string) contracts.Role

Role returns the role implementation by name.

Types

type AgentInput

type AgentInput struct {
	RunID              string
	Goal               string
	AcceptanceCriteria []task.AcceptanceCriterion
	TaskID             string
	RunDir             string
	WorkingDir         string
	BaseBranch         string
}

AgentInput is PDCA-specific input used to build the PDCA ADK agent.

type Factory

type Factory struct {
	// contains filtered or unexported fields
}

Factory builds and finalizes PDCA ADK agents.

func NewFactory

func NewFactory(cfg config.Config, maxIterations int, store *db.Store, tracker task.Tracker) *Factory

NewFactory constructs a PDCA agent factory.

func (*Factory) Build

func (*Factory) Finalize

func (w *Factory) Finalize(ctx context.Context, meta runpkg.RunMeta, payload runpkg.TaskPayload, finalSession session.Session) (runpkg.AgentOutcome, error)

func (*Factory) Name

func (w *Factory) Name() string

type Runner

type Runner interface {
	Run(ctx context.Context, req []byte, stdout, stderr, eventsLog io.Writer) (contracts.RawAgentResponse, int, error)
}

Runner executes a single role step using an ADK agent.

func NewRunner

func NewRunner(cfg config.AgentConfig, role contracts.Role, mcpServers map[string]agentconfig.MCPServerConfig) (Runner, error)

NewRunner creates a new Runner for the given role.

Directories

Path Synopsis
act
do

Jump to