reconcile

package
v0.0.12 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 5, 2026 License: MIT Imports: 11 Imported by: 0

Documentation

Overview

Package reconcile provides logic for reconciling run state between the database and the filesystem.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Run

func Run(ctx context.Context, db *sql.DB, normaDir string) error

Run reconciles the database with the filesystem by inserting missing step rows and corresponding timeline events for step directories found on disk.

Types

This section is empty.

Jump to