Documentation
¶
Index ¶
Constants ¶
const ( RolePlan = "plan" RoleDo = "do" RoleCheck = "check" RoleAct = "act" )
Variables ¶
This section is empty.
Functions ¶
Types ¶
type AgentInput ¶
type AgentInput struct {
RunID string
Goal string
AcceptanceCriteria []task.AcceptanceCriterion
TaskID string
RunDir string
WorkingDir string
BaseBranch string
}
AgentInput is PDCA-specific input used to build the PDCA ADK agent.
type Factory ¶
type Factory struct {
// contains filtered or unexported fields
}
Factory builds and finalizes PDCA ADK agents.
func NewFactory ¶
func NewFactory(cfg config.Config, maxIterations int, store *db.Store, tracker task.Tracker) *Factory
NewFactory constructs a PDCA agent factory.
func (*Factory) Build ¶
func (w *Factory) Build(ctx context.Context, meta runpkg.RunMeta, task runpkg.TaskPayload) (runpkg.AgentBuild, error)
type Runner ¶
type Runner interface {
Run(ctx context.Context, req []byte, stdout, stderr, eventsLog io.Writer) (contracts.RawAgentResponse, int, error)
}
Runner executes a single role step using an ADK agent.
func NewRunner ¶
func NewRunner(cfg config.AgentConfig, role contracts.Role, mcpServers map[string]agentconfig.MCPServerConfig) (Runner, error)
NewRunner creates a new Runner for the given role.
Click to show internal directories.
Click to hide internal directories.